***PROGRAM BY: TERESA FORT****;
***WRITTEN ON: 12-09-14*******;

***LAST MODIFIED BY:TFP***;
***LAST MODIFIED ON:12-09-14***;     

/*
NOTES:
This program makes a firm panel with firm size measures (employment and plants)


*/


*options obs=10000;


options obs=max;
%let s=1992;
%let e=2007;

*libname naics DIRECTORY NAME FOR THE FK CODES HERE;

*Use the FK codes available on the RDC servers;
  ***Note this is a legacy version of the codes.  Updated codes coming soon and should be used instead by future researchers;
  ***Also note that there is some risk involved in using the codes that are made based on on the 2010 LBD and the current (2012) LBD;
  ***In principle, LBDNUMS remain the same, but it is possible that they have changed.  Always some risk here...;
  

*Assign libnames;
libname aer "YOUR DATA DIRECTORY NAME HERE" ; 
libname naics "DIRECTORY NAME FOR THE FK CODES HERE";

*1. Make a panel from 1992-2007 with firm employment, employment shares, fknaics, imports, exports;

**First make a simple panel using firm id as a longitudinal link;

%macro make_panel1();
    %do y=&s %to &e;
	proc sort data=lbd.lbd&y.c(keep=lbdnum firmid sic naics bestsic bestnaics emp pay cbp_:) out=lbd&y;
	    by lbdnum;
	run;

	%if &y<2010 %then %do;
	    
	data fk_naics(keep=lbdnum fk_naics02);
	    set naics.naics&y;
	    splits=sum(fk_n97_splits,fk_sic97_splits,fk_sic87_splits);
	    if splits<25;
	run;

	proc sort data=fk_naics;
	    by lbdnum;
	run;
	data lbd&y;
	    merge lbd&y(in=a) fk_naics(in=b);
	    by lbdnum;
	    if a=1;
	run;
	%end;
    
	
   *Use the fk codes for this;   **If not available (eg, 2010), use bestnaics;
   
	data lbd&y;
	    set lbd&y;
	       
	      if substr(fk_naics02,1,2)="11" then industry="Ag_FandF";
              if substr(fk_naics02,1,1)="3" then industry="Manuf";
              if substr(fk_naics02,1,2)="21" then industry="Mining";
              if substr(fk_naics02,1,2)="22" | substr(fk_naics02,1,2)="48" | substr(fk_naics02,1,2)="49" then industry="Trans_War_Util";
              if substr(fk_naics02,1,2)="23" then industry="Constr";
              if substr(fk_naics02,1,2)="42" then industry="Whole";
              if substr(fk_naics02,1,2)="44" | substr(fk_naics02,1,2)="45" then industry="Retail";
              if substr(fk_naics02,1,2)="52" | substr(fk_naics02,1,2)="53" then industry="Fin_Ins_Real";
              if substr(fk_naics02,1,2)="51" | substr(fk_naics02,1,2)="54" | substr(fk_naics02,1,2)="55" | substr(fk_naics02,1,2)="56" | substr(fk_naics02,1,2)="61" | 
                 substr(fk_naics02,1,2)="62" | substr(fk_naics02,1,2)="71" | substr(fk_naics02,1,2)="72" | substr(fk_naics02,1,2)="81" then industry="Services";
	      if substr(fk_naics02,1,2)='92' then industry='Public';   
	   	   
          *Make more aggregate definition;
	   if industry="Manuf" then ind_agg="MANF" ;
	   if industry="Ag_FandF" | industry="Mining" | industry="Trans_War_Util" | industry="Constr" | industry="Public" then ind_agg="OTHR" ;
	   * ind_agg="FIRE" if industry="Fin_Ins_";
	   if industry="Services" | industry="Fin_Ins_" then ind_agg="SERV" ; 
	   if industry="Whole" then ind_agg="WHOL" ;
	   if industry="Retail" then ind_agg="RETL" ;
	  
          *Make employment variables for firm shares;
	   if ind_agg="MANF" then type='manf';
	   if ind_agg="SERV" then type='serv';
	   if  substr(fk_naics02,1,2)="54" | substr(fk_naics02,1,2)="55" then type='mpro';
	   if ind_agg="OTHR" | ind_agg="RETL" then type='othr';
	   if ind_agg="WHOL" then type='whol';
	   if type='' then type='miss';
	   
	    if firmid~=' ' ;
       run;

    *Calculate firm employment by sector type;
	proc sort data=lbd&y;
	    by firmid type;
	run;
	
	proc means sum noprint data=lbd&y;
	    var emp pay ;
	    by firmid type;
	    output out=firm&y(drop=_type_ rename=(_freq_=plants)) sum()=;
	run;

       proc transpose data=firm&y out=firm&y._2(drop=_name_ _label_) prefix=emp_; 
           by firmid;
           id type;
           var emp;
       run;
*****************;


     *Calculate firms majority employment by sector;
	data firm_sector1;
	    set lbd&y(keep=firmid fk_naics02 emp);
	    sector=substr(fk_naics02,1,2);
	run;
	
	proc sort data=firm_sector1;
	    by firmid sector;
	run;
      
     *Aggregate to firm-sector level;
	proc means sum noprint data=firm_sector1;
	    by firmid sector;
	    var emp;
	    output out=firm_sector2(drop=_type_ _freq_) sum()=;
	run;

     *Limit to majority employment industry;
	proc sort data=firm_sector2;
	    by firmid emp;
	run;
	data firm_sector3;
	    set firm_sector2;
	    by firmid;
	    if last.firmid=1;
	    label sector="Majority 2-digit sector of the firm";
	run;
	  

    *Calculate firms majority wholesale industry by employment;
     data firm_whole1;
	    set lbd&y(keep=firmid fk_naics02 emp);
	    if substr(fk_naics02,1,2)='42';
	run;
	
	proc sort data=firm_whole1;
	    by firmid fk_naics02;
	run;
      
     *Aggregate to firm-industry level;
	proc means sum noprint data=firm_whole1;
	    by firmid fk_naics02;
	    var emp;
	    output out=firm_whole2(drop=_type_ _freq_) sum()=;
	run;

     *Limit to majority employment industry;
	proc sort data=firm_whole2;
	    by firmid emp;
	run;
	data firm_whole3(drop=fk_naics02 emp);
	    set firm_whole2;
	    by firmid;
	    if last.firmid=1;
	    whole_ind=fk_naics02;
	    label whole_ind="Majority wholesale industry of the firm";
	run;
	  
  

   *Add total establishments, emp, and pay;
	proc means sum noprint data=firm&y;
	    by firmid;
	    var emp pay plants ;
	    output out=firm3(keep=emp pay plants firmid) sum()=;
	run;
	
	data firm&y._3;
	    merge firm&y._2 firm3 firm_sector3(drop=emp) firm_whole3;
	    by firmid;
	run;
	
      %end;
    %mend;

%make_panel1();




*2.  Combine all years;


%macro panel5();
    
data firm_panel;
    set firm&s._3;
    year=&s;
    
run;

%let x=%eval(&s+1);

%do y=&x %to &e ;

data firm_panel;
    set  firm_panel firm&y._3(in=b);
    if b=1 then year=&y;
run;

%end;
%mend;
%panel5();


*3. Get firmage;
    proc sort data=lbd.firm_long_new_emp(keep=firmid firmage year) out=firm_age;
	where firmid~=' ';
	by firmid year;
    run;


proc sort data=firm_panel;
    by firmid year;
run;

data firm_panel2;
    merge firm_panel(in=a) firm_age;
    by firmid year;
    if a=1;
run;


*5. Output final dataset;
data aer.firm_panel;
    set firm_panel2 ;
run;
