
***PROGRAM BY: TERESA FORT****;
***WRITTEN ON: 12-09-14*******;

***LAST MODIFIED BY:TFP***;
***LAST MODIFIED ON:12-09-14***;     

/*
NOTES:
This program makes an annual dataset of the 2007 import data and matches it to firmids

Matching is done directly to the EC data whenever possible

*/


**************PROGRAM BY TERESA FORT, 02/22/2012******************;

**The code I use to identify active estabs in the BR is a modification of code Javi used;
**It is necssary to modify this code since there are records with positive payroll that map the same ein to multiple firmids;
 ***Eliminating the N and D records from the BR does a lot to rectify these issues;
  **Since an N or D record may indicate a plant that was closed mid-year, I add the N & D with payroll>0 back in IF it does not conflict with an ein-firmid relationship from an active record;



*OPTIONS OBS=100000;
options obs=max;

*Assign libnames;
libname aer "YOUR DATA DIRECTORY NAME HERE" ; 


*1. Make a concordance between Firmid and EINs from the BR;

%let listbr=act cfn ein;
%let listbr2007=alpha;

%let y=2007;


%macro make_bridge();


%if &y>2001 %then %do;
  %let listbr2=alpha;
%end;	


data ids(keep=firmid cfn ein payroll act alpha) ids_add(keep=firmid cfn ein payroll act alpha) subs(keep=firmid cfn ein payroll act alpha) ;
   set ssl.ssl&y.mu(keep=&listbr alpha rap in=a) ssl.ssl&y.su(keep=&listbr &listbr2 acqp1 acqp2 acqp3 acqp4 pdiv ac943p in=b);
   length firmid $10 ;

  *Make firmid variable;
   if alpha=' ' then firmid='0'||ein;
   if alpha~=' ' then firmid=left(trim(alpha))||"0000";

  *Make payroll variable;
   payroll=rap;
   if b=1 then payroll=acqp1+acqp2+acqp3+acqp4 ;
   
  *Only records with a firmid and ein are useful;
   if firmid^=' ';
   *if cfn^=' ';
   if ein^=' ';  
   if ein^='000000000';
   if left(trim(ein))~='.';
   if left(trim(firmid))^='.';
   
  *Code to identify active establishments; 
   if act='D' | act='G' | act='N' then drop=1;  *Drop records that are deletes, ghosts or non-actives;
   if pdiv='M' then do;
     drop=1;
     add_subs=1;  *Submaster records;
     end;
   
  *Additional records to add back in if not conflicting;
   if a=1 & payroll>0 & act='D' then add_recs=1;
   if a=1 & payroll>0 &  act='N' then add_recs=1;   *Might be possible for an MU to have act='N' and positive payroll, in which case it was a business that closed during year;
   
  *Output datasets;
    if drop~=1 then output ids;
    if add_recs=1 then output ids_add;
    if add_subs=1 then output subs;
run;


**First eliminate legitimate dupes;
  *Do this methodically in case the ein maps to multiple firmids;
    *Ssum payroll for each ein-firmid combination;
	proc sort data=ids;
	    by ein firmid;
	run;
	proc means sum noprint data=ids;
	    by ein firmid ;
	    var payroll;
	    output out=ids2(keep=ein firmid payroll) sum(payroll)=;
	run;

**Add back records of firms that went out of business during the year if they do not create dupes;
	proc sort data=ids_add;
	    by ein firmid  ;
	run;
	proc means sum noprint data=ids_add;
	    by ein firmid;
	    var payroll;
	    output out=ids_add(keep=ein firmid payroll) sum(payroll)=;
	run;
	
      *Dataset of ein values in data;
	proc sort nodupkey data=ids2(keep=ein) out=id_ein;
	    by ein;
	run;
	
	data ids_add2;
	    merge id_ein(in=a) ids_add(in=b);
	    by ein;
	    if a=0;	    
	run;

**Add back submaster records if they do not create dupes;
	proc sort data=subs;
	    by ein firmid  ;
	run;
	proc means sum noprint data=subs;
	    by ein firmid;
	    var payroll;
	    output out=subs(keep=ein firmid payroll) sum(payroll)=;
	run;
	
      *Dataset of ein values in data;
	data ids_subs;
	    merge id_ein(in=a) subs(in=b);
	    by ein;
	    if a=0;	    
	run;

	data ids3;
	    set ids2 ids_add2 ids_subs;
	run;
	
  *Double check no dupes were created;
    **If records deleted, this indicates a problem in code;
	proc sort nodupkey data=ids3;
	    by ein firmid;
	run;	  
	
**Ensure eins match to unique firmid;
	proc sort data=ids3;
	    by ein payroll firmid;
	run;	

     *Output final dataset;
	data concord&y dupes&y;
	    set ids3;
	    by ein payroll firmid;
	    if first.ein=1 & last.ein=1 then dupe_flag=0;
	    else dupe_flag=1;
	    if last.ein then output concord&y;
	    else output dupes&y;
	run;	

    %mend;

%make_bridge();
*****************************************************************;



*2. Make a concordance to the 2007 Economic Census data;
****************************************************************;

%let list1=ein alpha survu_id naics_old naics_new naics_bridge tabbed tvs sw;
%let list2=ein alpha survu_id naics_old naics_new tabbed sales pay_ann;
%let list3=ein alpha survu_id naics_old naics_new tabbed sales pay_ann;

data census (drop=temp temp2 survt ein_t ein2) ;
  length temp2 $ 11 ;
   set cmf.cmf2007 (in=a keep=&list1 rename=(sw=payroll ein=ein_t))
       cmi.cmi2007(in=b keep=&list1 rename=(sw=payroll ein=ein_t survu_id=survt))
       cfi.cfi2007base (in=c keep=&list2 rename=(pay_ann=payroll))
       ccn.ccn2007(in=d keep=&list1 rename=(sw=payroll ein=ein_t survu_id=survt))
       crt.crt2007base(in=e keep=&list3 rename=(pay_ann=payroll))
       csr.csr2007base(in=f keep=&list3 rename=(pay_ann=payroll ein=ein2))
       cut.cut2007base(in=g keep=&list3 rename=(pay_ann=payroll))
       cwh.cwh2007base(in=h keep=&list3 rename=(pay_ann=payroll)) ;

       *Make consistent ein variable;
       if ein_t~=. then do;
        temp=1000000000+ein_t;
        temp2=temp;
        ein=substr(left(trim(temp2)),2);
       end;
        if f=1 then ein=left(trim(ein2));
 
       *Make consistent survu_id variable;
        if survt~=. then survu_id=survt;

       *Create variable to keep track of what file the record came from ;
       if a=1        then source='cmf' ;
         else if b=1 then source='cmi' ;
         else if c=1 then source='cfi' ;
         else if d=1 then source='ccn' ;
         else if e=1 then source='crt' ;
         else if f=1 then source='csr' ;
         else if g=1 then source='cut' ;
         else if h=1 then source='cwh' ;
run ;



**Make EIN-FIRMID Concordance***;

***Pull in EIN and alpha information from the Census;
data census;
  set census(keep=survu_id alpha ein naics_old naics_new payroll tvs sales tabbed source
    rename=(naics_old=naics02) rename=(naics_new=naics07 survu_id=survuid));
  *Make firmid variable;
    if alpha=' ' then firmid='0'||ein;
    if alpha~=' ' then firmid=alpha||"0000";
  *Make sales variable;
   receipts=tvs;
   if tvs=. then receipts=sales;
run;


*Make ein-firmid concordance;
data census_tabbed;
  set census;
  if tabbed~='N';
run;


proc sort  data=census_tabbed out=ein_conc; by ein firmid; run;

proc means sum noprint data=ein_conc;
    by ein firmid;
    var payroll;
    output out=ein_concb sum()=;
run;

proc sort data=ein_concb;
    by ein;
run;

data ein_conc2 dupes;
  set ein_concb(keep=ein firmid payroll );
  by ein ;
  if first.ein=1 and last.ein=1 then output ein_conc2;
  else output dupes;
run;

***Separate dupes;
proc sort data=dupes; by ein payroll; run;

data dupes_add dupes_chuck;
  set dupes;
  by ein;
  dupe_flag=1;
  if last.ein=1 then output dupes_add;
  else output dupes_chuck;
run;

data ein_conc3;
  set ein_conc2(in=a) dupes_add(in=b);
  concord_source='Census';
  if a=1 then dupe_flag=0;
  else dupe_flag=1;
  if ein~='000000000' & ein~='009999999' & ein~=' ';
run;
****************************************************************;


*3. Combine the Census concordance with the BR concordance from trade match program;
****************************************************************;
 proc sort data=concord2007 out=conc_br(rename=(firmid=firmid_br payroll=payroll_br));
					 by ein;
				     run;

proc sort data=ein_conc3;
    by ein;
run;

data ein_clean conflict;
    merge ein_conc3(in=a rename=(firmid=firmid_cen)) conc_br(in=b);
    by ein;
    if a=1 then firmid=firmid_cen;
    if a=0 then firmid=firmid_br;
    if a=0 then concord_source="BR";
    if firmid_cen~=firmid_br & a~=0 then conflict=1;
    if conflict=1 then output conflict;
    if conflict=1 | conflict=. then output ein_clean;
run;



*4.  Bring in Import Data ;
****************************************************************;
*Bring in the aggregated import file;
  data imports_alt(drop=related value temp);
     length ein $9;
     length ein_importer $9;
     set imp.imp2007(keep=ein ein_ult type value country  related hs qty: rename=(ein=temp ein_ult=ult_cnsg));
     if value<=0 then delete;
     ivalue=value;
     importer=left(temp);
     importer=left(importer);

    *Make ein_importer variable;
     if substr(importer,3,1) = '-' then ein_importer=substr(importer,1,2)||substr(importer,4,7);
     if substr(importer,3,1) ^= '-' then ein_importer=substr(importer,1,9);
    dashflg_imp=index(ein_importer,'-');
     if dashflg_imp>0 then ein_importer='mu dashes';

    *Make ein variable from ultimate consignee;
     temp2=left(ult_cnsg);
     temp2=left(temp2);
     if substr(temp2,3,1) = '-' then ein=substr(temp2,1,2)||substr(temp2,4,7);
     if substr(temp2,3,1) ^= '-' then ein=substr(temp2,1,9);
     dashflg=index(ein,'-');
     if dashflg>0 then ein='mu dashes';

    *Make ritrans variable;
     itrans=1;
     if related='Y' then do;
        ritrans=1;
	rp_ivalue=ivalue;
	end;
    
     if related='N' then ritrans=0;


     if substr(ein,1,1) in ('A','B','C','D','E','F','G','H','I','J',
       'K','L','M','N','O','P','Q','R','S','T',
       'U','V','W','X','W','X','Y','Z')
     then ein='letters';
     if substr(ein_importer,1,1) in ('A','B','C','D','E','F','G','H','I','J',
       'K','L','M','N','O','P','Q','R','S','T',
       'U','V','W','X','W','X','Y','Z')
     then ein_importer='letters';
     if ein=' ' then ein='missing';
     if ein_importer=' ' then ein_importer='missing';
 
   *Limit by type;
   if type in ('1','2','5');      ***** consumption imports **********;

run;

data imports_alt;
    set imports_alt;
    ein_uc=ein;
    ein_source="ult cons";
    if ein="missing" | ein='letters' | ein='mu dashes' | ein='000000000' then do;
    if ein_importer~="missing" & ein_importer~='letters' & ein_importer~='mu dashes' & ein_importer~='000000000' then do;
      ein=ein_importer;
      ein_source="importer";
    end;
  end;
  if ein_uc=ein_importer then ein_source="both";
run;

proc freq data=imports_alt;  tables ein_source; run;				     


*********************************************;


*5. Merge Trade data to Firmids;
proc sort data=imports_alt ; by ein; run;
proc sort data=ein_clean; by ein; run;

data imports_2007_alt imports_nomatch_a;
  merge imports_alt(in=a) ein_clean(in=b);
  by ein; 
  if ivalue=. then ivalue=0;
  if itrans=. then itrans=0;
  if firmid_lbd=' ' then firmid_lbd=firmid;
  if a=1 and b=1 then output imports_2007_alt;
  if a=1 and b=0 then output imports_nomatch_a; 
run;


*6.  Prepare data for export to STATA;
data imports;
    set imports_2007_alt(keep=firmid ivalue rp_ivalue country hs);
    where substr(hs,1,2)~='27';  *Eliminate fuels;
run;

*Aggregate to firm-hs-country level;
proc sort data=imports;
    by firmid country hs;
run;
proc means sum noprint data=imports;
    by firmid country hs;
    var ivalue rp_ivalue;
    output out=imports sum()=;
run;

**Export dataset to STATA;
 proc export data=imports(keep=firmid ivalue rp_ivalue country hs)
    outfile="YOUR DATA DIRECTORY NAME HERE/imports_firm_prod_country.dta"
    dbms=dta replace;
    run; 





***Calculate match rates for ein merge;
data match_rate1;
    length matched $ 9;
  set imports_2007_alt(in=a) imports_nomatch_a(in=b) ;
  if a=1 then matched='yes';
  if b=1 then matched='no';
  if ein='000000000' then matched='000000000';
  if ein='missing' then matched='missing';
  if ein='mu dashes' then matched='mu dashes';
  if ein='letters' then matched='letters';
run;

proc sort data=match_rate1; by matched; run;

proc means sum noprint data=match_rate1;
  by matched;
  var ivalue itrans;
output out=match_rate2(rename=(_freq_=count)) sum(ivalue itrans)=total_value total_trans;
run;

*calculate denominator;
proc means sum noprint data=match_rate2;
  var count total_value total_trans;
  output out=match_rate3 sum(total_value total_trans count)=value trans HS_firm_c;
run;

*combine totals;
data aer.trade_mr_2007;
  merge match_rate2 match_rate3;
  by _type_;
  share_value=total_value/value;
  share_trans=total_trans/trans;
  share_HS_firm_coun=count/HS_firm_c;
run;
***********************************************;
