
****PROGRAM BY: TERESA FORT;
***WRITTEN ON: 11-23-14 ;

***LAST MODIFIED ON: 12-10-14 ;
***LAST MODIFIED BY: TFP;

**THIS PROGRAM MAKES A FIRM-LEVEL PANEL OF THE FGP PLANTS IN 2007 ;

***This program makes a firm-level dataset of the Census special estab questions;

option obs=max;
*options obs=100000;


*Assign libnames;
libname aer "/DIRECTORY NAME FOR THE FK CODES HERE" ; 

libname naics "FK NAICS DIRECTORY NAME HERE";


%let list=activity census contract design fgp lbdnum firmid firstyear lastyear emp_lbd pay_lbd naics02 naics07 fgp sales payann empl industry_asked ;


*Pull in establishment level data;
data firm;
  set aer.estabs_2007 (keep=&list rename=(empl=emp_cen07 payann=payann_cen07));
  if census="MANUF" then do;
      emp_manuf07=emp_lbd;
      estab_manuf07=1;
      end;
  
  if census="WHOLE" then do ;
     emp_whole07=emp_lbd;
     estab_whole07=1;
     if fgp="YES" then fgp_count=1;  /*FGP Count of WHOLESALE estabs that are in firm */
     if fgp="NO" then fgp_count_no=1;
     if fgp="" then fgp_count_miss=1;
     end; 
run;

*Calculate firms majority wholesale industry by employment;
     data firm_whole1;
	    set firm(keep=firmid naics07 emp_lbd);
	    if substr(naics07,1,2)='42';
	run;
	
	proc sort data=firm_whole1;
	    by firmid naics07;
	run;
      
     *Aggregate to firm-industry level;
	proc means sum noprint data=firm_whole1;
	    by firmid naics07;
	    var emp_lbd;
	    output out=firm_whole2(drop=_type_ _freq_) sum()=;
	run;

     *Limit to majority employment industry;
	proc sort data=firm_whole2;
	    by firmid emp_lbd;
	run;
	data firm_whole3(drop=naics07 emp_lbd);
	    set firm_whole2;
	    by firmid;
	    if last.firmid=1;
	    whole_ind_2007=naics07;
	    label whole_ind_2007="Majority wholesale industry of the firm in 2007";
	run;
	  

*Aggregate to the firm level;
proc sort data=firm;
    by firmid;
run;

proc means sum noprint data=firm;
    var emp_manuf07 emp_whole07 estab_manuf07 estab_whole07 fgp_count fgp_count fgp_count_no fgp_count_miss sales  ;
    by firmid;
    output out=firm1(drop=_TYPE_ _FREQ_) sum()=;
run;

data firm2;
    set firm1;
    if estab_manuf07>=1 then census="MANUF";
    if estab_whole07>=1 then do;
	if census="" then census="WHOLE";
	if census="MANUF" then census="BOTH";
	end; 

 *Make FGP variable;
    if census="WHOLE" then do;	
      if fgp_count>=1 then fgp_firm="YES";
      if fgp_count=. & fgp_count_miss=. then fgp_firm="NO";
      if fgp_count=. & fgp_count_miss>0 then fgp_firm="MISS";
      end;
run;


*Pull total employment from the LBD; 
  data lbd;
      set lbd.lbd2007c(keep=cbp_bestnaics firmid emp);     
       *Limit records in accordance with Javi directions;
	  * if cbp_bestnaics=1;
  run;

proc sort data=lbd;
    by firmid;
run;

proc means sum noprint data=lbd;
    by firmid;
    var emp;
    output out=lbd_emp(keep=firmid emp rename=(emp=emp_lbd07)) sum()=;
run;
  
  
*Add majority wholesale firm and lbd emp;
data firm2;
   merge firm2(in=a) firm_whole3 lbd_emp(in=b);
   by firmid;
   if b=1 then in_lbd07="yes";
   
   if a=1 ;
run;
	 

    
*Construct firm panel with imports for the FGP firms;
  *FGP firms with no manuf plants in 2007;
proc sort data=firm2;
    by firmid;
run;

proc sort data=aer.firm_panel out=panel;
    by firmid;
run;

data firm3 check_firm2 check_firm3 ;
    merge firm2(in=a) panel(in=b);
    by firmid;

    firms=1;

    *Make 2007 emp variable from the FGP dataset;
    emp_mw_2007=sum(emp_manuf07,emp_whole07);

    *Fix incorrect FK codes (see README for details);
    if census="WHOLE" & year=2007 & emp_manf>0 then do;
	emp_manf=0;
	emp_whol=emp_whole07;
	transfer=1;
	end;
    *Make employment share variables;
    if emp~=0 then do;	
      share_manf=emp_manf/emp;
      share_whole=emp_whol/emp;
      end;

    
   *Fix the emp sector variables (need a zero if not populated);
    emp_manf_pos=emp_manf;
    if emp_othr=. then emp_othr=0;
    if emp_serv=. then emp_serv=0;
    if emp_manf=. then emp_manf=0;
    if emp_mpro=. then emp_mpro=0;
    if emp_whol=. then emp_whol=0;
    
   *Make wage variable;
    if emp~=0 & pay~=0 then wage=pay/emp;  
    
    *Fix missing year variable for firms not in the LBD and flag LBD status;
    if a=1 & b=0 then do;
	year=2007;
	lbd07_status="Missing";
	end;
    if b=1 then lbd07_status="There";  /*Note that this does not address records that exist in the LBD in other years but not 2007--will drop all non-LBD records */
    
  
    *Limit to 2007 wholesale firms ;
    if a=1 & census="WHOLE" then output firm3 ;  /* Limit to Wholesale firms.  */
    if a=1 then output check_firm2;
    if a=1 & census="WHOLE" & year=2007 then output check_firm3;
    
run;
**********************************;

    

data firm4;
    set firm3;
    if census="WHOLE" & year=2007 & emp_manf>0 then do;
	emp_manf=0;
	emp_whol=emp_whole07;
	transfer=1;
	end;
    if emp~=0 then do;
	
    share_manf=emp_manf/emp;
    share_whole=emp_whol/emp;
    end;

run;



*Flag crazy outliers;
proc sort data=firm4;
    by year;
run;

proc means noprint data=firm4;
    by year;
    var emp wage ;
    output out=avgs(drop=_TYPE_ _FREQ_) mean(emp wage)=avg_wage avg_emp ;
run;

data firm5(drop=avg:)  outliers;
    merge firm4 avgs;
    by year;
    if wage>avg_wage*1000 then outlier=1;
    if emp>avg_emp*1000 then outlier=1;
    if outlier=1 then output outliers;
    if outlier=1 | outlier=. then  output firm5;
run;


***Export to STATA;
proc export data=firm5
outfile="YOUR DATA DIRECTORY NAME HERE/fgp_panel.dta"
dbms=dta replace;
run; 



