****************PROGRAM WRITTEN BY: TERESA FORT************
****************PROGRAM WRITTEN ON: 12-09-14***************

************************************************************
/*This program pull in a panel of 2007 FGP and non-FGP wholesale firms.
  The program performs the following tasks:
  1.  Analysis of 2007 characteristics and import behavior
 
*/
  


**Set directories



capture log close
log using "$output/LOG_Stata_04_FGP_Analysis_12-10-14.txt", replace text


use fgp_panel.dta, clear

*1.  Analysis of 2007 characteristics and import behavior
**************************************************************

*1a. Industry concentration of FGPs
keep if year==2007 
keep if in_lbd=="yes" /* This drops records that are not in the LBD in 2007 but present in other years  */
                      
  /*Note that we keep records with zero employment since they generally have sales>0 and emp refers to March 12 only */
keep if fgp_firm~="MIS"

*Flag whether firm's majority industry was asked question
**Note that it is important to use the whole_ind_2007 variable--unclear whether discrepancies are due to issues with fk codes or estabs in LBD  */
gen naics07=whole_ind_2007  
merge m:1 naics07 using "$Q26/Q26_ind.dta"  /* Industry code information available in SAS program SAS_03_Make_Census...  */
drop _merge

gen count=1
tab count if question26_ind=="no"  & fgp_firm=="YES"
tab count if question26_ind=="yes"  & fgp_firm=="YES"


*Assess industry concentration of FGP firms
gen fgp_ind_count=1 if fgp_firm=="YES"
gen firm_tot=1 if fgp_firm=="NO" | fgp_firm=="YES"
replace fgp_ind_count=0 if question=="no"
replace firm_tot=0 if question=="no"


**NAICS4 concentration
preserve
  gen naics4=substr(whole_ind_2007,1,4)
  collapse (sum) fgp_ind_count firm_tot, by(naics4)
  gen share=fgp_ind_count/firm_tot
  sort share
  browse
  
  *Get naics code descriptions
   merge 1:1 naics4 using "$naics/naics4.dta"
   drop if _merge==2
  sort share
  browse share naics4_d
  outsheet naics4 naics4_desc share using "$disc/output/NAICS4_FGP_concetration.out", comma replace
restore

**Disclosure Statistics**
preserve

gen naics4=substr(whole_ind_2007,1,4)
keep sales firmid fgp_firm fgp_ind_count naics4 firm_tot 
keep if firm_tot==1 | fgp_ind_count==1
drop if fgp_firm=="MIS"

gen tvs=sales
keep firmid tvs fgp_firm naics4
egen naics_group=group(naics4)
summ naics_group
global max=r(max)
save temp.dta, replace

 capture log close
     log using $disc/support/NAICS4_FGP_concetration_Disc.txt, replace text
     qui log off

    foreach var in YES NO {
      forvalues i=1/$max {
         keep if fgp_firm=="`var'" & naics_group==`i'
	 qui log on
	 di "FGP firm status is `var' and NAICS is " naics4 
	 qui log off
	 do disclose_firm_level
	 use temp.dta, clear
	 }
	 }
  log close

erase temp.dta


******************************************************************************

*1b. Analyze 2007 Import behavior
  
**Pull in import data  (for now use data from moo--fix this before disclosure)
merge 1:m firmid using "imports_firm_prod_country.dta"  /*Note that fuels eliminated from these data (27) */
keep if _merge~=2  /* Drop firms that are not in the FGP dataset  */ 
drop _merge


*Assess total offshoring
gen imports=ivalue/1000
gen off_share=imports/sales
gen emp_share=(imports*1000)/emp


*Do these statistics conditional on importing and report fraction of importers
preserve
  collapse (sum) imports off_share emp_share (mean) sales emp_whole07 emp, by(firmid fgp_firm)
  gen importer=1 if imports~=0
  replace importer=0 if imports==0
  save temp.dta, replace
  foreach var in imports off_share emp_share {
     replace `var'=. if `var'==0
     }
  log using "$disc/output/Summ_Stats_2007.txt", replace text
      tabstat importer imports off_share emp_share sales emp_whole emp , by(fgp_firm) stats(mean sd )
   log close   


***Disclosure Statistics***
use temp.dta, clear

gen tvs=sales
keep firmid tvs fgp_firm importer


save temp.dta, replace

 capture log close
     log using $disc/support/Summ_Stats_2007_Disc.txt, replace text
     qui log off

    foreach var in YES NO {
      foreach val in 0 1 {
         keep if fgp_firm=="`var'" & importer==`val'
	 qui log on
	 di "FGP firm status is `var' and importer is `val'"  
	 qui log off
	 do disclose_firm_level
	 use temp.dta, clear
	 }
	 }
  log close

erase temp.dta

restore


*Country imports by FGP status
preserve
   drop if country=="" /* Tabs based only on importers  */
   collapse (sum) imports (mean) sales, by(firmid fgp_firm country)
   save temp.dta, replace  /*Firm-level dataset for disclosure */
   gen firms=1
   bysort fgp_firm firmid: gen firm_unique=1 if _n==1
   collapse (sum) imports firms firm_unique (mean) imports_mean=imports, by(fgp_firm country)
   gen code_TD=country
   merge m:1 code_TD using "$moo/country_clean.dta", keepusing(code_TD iso3)
   drop if _merge==2
   drop _merge
   
   sort fgp_firm imports
   bysort fgp_firm: egen imports_tot=sum(imports)
   gen import_share=imports/imports_tot
   
   bysort fgp_firm: egen firm_tot=sum(firm_unique)
   gen firm_share=firms/firm_tot
  
    
   bysort fgp_firm: egen rank_value=rank(import_share), field
   bysort fgp_firm: egen rank_firms=rank(firm_share), field
       
     sort fgp_firm rank_value rank_firms
     keep if fgp_firm~="MIS" & (rank_value<11 | rank_firm<11)
     outsheet country fgp_firm import_share firm_share rank_value rank_firms using "$disc/output/Summ_Stats_Country.out", comma replace 
     *browse country fgp_firm import_share firm_share rank_value rank_firms
     
     contract country
     save temp2.dta, replace
     
**Disclosure Statistics**
use temp.dta, clear
merge m:1 country using temp2.dta
keep if _merge==3

gen tvs=sales
keep tvs firmid fgp_firm country 

egen country_group=group(country)
summ country_group
global max=r(max)
save temp.dta, replace

 capture log close
     log using $disc/support/Summ_Stats_Country_Disc.txt, replace text
     qui log off

    foreach var in YES NO {
      forvalues i=1/$max {
         keep if fgp_firm=="`var'" & country_group==`i'
	 qui log on
	 di "FGP firm status is `var' and country is " country 
	 qui log off
	 do disclose_firm_level
	 use temp.dta, clear
	 }
	 }
  log close

erase temp.dta 
restore



*Product imports by FGP status

**Do at 2 digit level
preserve
gen hs2=substr(hs,1,2)
save temp.dta, replace

collapse (sum) imports, by(fgp_firm hs2)
   
   sort fgp_firm imports
   bysort fgp_firm: egen imports_tot=sum(imports)
   gen import_share=imports/imports_tot
   
   bysort fgp_firm: egen hs_rank=rank(import_share), field
   
   
     sort fgp_firm hs_rank
     *browse fgp_firm hs_rank hs2 if fgp_firm~="MIS" & hs_rank<6
     
     outsheet fgp_firm hs_rank hs2 import_share if fgp_firm~="MIS" & hs_rank<6 using "$disc/output/Summ_Stats_HS.out", comma replace
     keep if hs_rank<6
     contract hs2
     save temp2.dta, replace


**Disclosure Statistics**
use temp.dta, clear
merge m:1 hs2 using temp2.dta
keep if _merge==3

collapse (mean) sales, by(firmid fgp_firm hs2)

gen tvs=sales
keep tvs firmid fgp_firm hs2

egen country_group=group(hs2)
summ country_group
global max=r(max)
save temp.dta, replace

 capture log close
     log using $disc/support/Summ_Stats_HS_Disc.txt, replace text
     qui log off

    foreach var in YES NO {
      forvalues i=1/$max {
         keep if fgp_firm=="`var'" & country_group==`i'
	 qui log on
	 di "FGP firm status is `var' and HS is " hs2 
	 qui log off
	 do disclose_firm_level
	 use temp.dta, clear
	 }
	 }
  log close

erase temp.dta   
erase temp2.dta 
     
restore
  


