****************PROGRAM WRITTEN BY: TERESA FORT************
****************PROGRAM WRITTEN ON: 12-09-14***************

************************************************************
/*This program pull in a panel of 2007 FGP and non-FGP wholesale firms.
    The program performs the following tasks:
 
  2.  Analysis of panel characteristics
  
*/
  
set more off

**Set directories
cd "/YOUR DATA DIRECTORY NAME HERE"
global output="YOUR OUTPUT DIRECTORY NAME HERE"
global Q26="WHEREVER YOU PUT THE INDUSTRY INFORMATION DATA "
global naics="WHEREVER YOU PUT THE NAICS DESCRIPTION DATA"
global disc="YOUR DISCLOSURE DIRECTORY"

capture log close
log using "$output/LOG_Stata_05_FGP_Panel_Analysis_12-10-14.txt", replace text


use fgp_panel.dta, clear

keep if in_lbd=="yes" /* This drops records that are not in the LBD in 2007  */
                      
keep if fgp_firm~="MIS"

*1. Address Outlier Issues
*************************************

*1a. Smooth out implausible spikes in employment from year t to year t+1
******

*Set time series variables

egen firmid_num=group(firmid)
sort firmid_num year
tsset firmid_num year

*Smooth out total employment
gen jump=(emp-l.emp)/l.emp
sort firmid_num year
bysort firmid: replace jump=0 if _n==1

sort firmid_num year
gen jump2=(emp-f.emp)/f.emp

gen outlier3=1 if abs(jump)>5 & jump~=. & abs(jump2)>5 & jump2~=.
bysort firmid: egen outlier4=mean(outlier3)

*browse firmid year emp jump* outlier3 if outlier4==1

*Replace with average year information in these cases
sort firmid_num year
gen empt=(l.emp+f.emp)/2
replace emp=empt if outlier3==1

drop jump* outlier3 outlier4 empt

set more off 
*Smooth out additional time series variables
foreach var in emp_manf emp_manf_pos emp_whol emp_serv emp_othr emp_mpro wage {
  sort firmid_num year
  gen jump=(`var'-l.`var')/l.`var'
  sort firmid_num year
  bysort firmid: replace jump=0 if _n==1

  sort firmid_num year
  gen jump2=(`var'-f.`var')/f.`var'

  gen outlier3=1 if abs(jump)>5 & jump~=. & abs(jump2)>5 & jump2~=.
  bysort firmid: egen outlier4=mean(outlier3)
  
 *Replace with average year information in these cases
  sort firmid_num year
  gen empt=(l.`var'+f.`var')/2
  replace `var'=empt if outlier3==1
  
  drop jump* outlier3 outlier4 empt
  }

*1b. Drop impossible wages
*****
gen outlier2=1 if wage>10000 & wage~=.
replace wage=. if outlier2==1
******
******

****Save Dataset for Disclosure Analysis****
save temp.dta, replace  


*keep if fgp_firm~="MIS"

**CAUTION: SOME OF THE VARIABLES ARE FROM THE 2007 CWH--NOT PANEL VARIABLES--REFER TO SAS PROGRAM or note that they are the same in all years**


*Make relative to industry mean variables
foreach var in emp emp_manf emp_manf_pos emp_whol emp_serv emp_othr emp_mpro wage plants firmage share_manf share_whole {
  bysort whole_ind year: egen ind_`var'=mean(`var')
  gen `var'_rel=`var'/ind_`var'
  }

*Make manuf firm count
gen firms_man=1 if emp_manf>0 & emp_manf~=.

*Collapse data by FPG Status
collapse (sum) firms firms_man emp_tot=emp (mean) emp emp_manf emp_manf_pos emp_whol emp_serv emp_othr emp_mpro wage plants firmage share_manf share_whole ///
emp_manf_rel emp_manf_pos_rel emp_whol_rel emp_serv_rel emp_othr_rel emp_mpro_rel wage_rel plants_rel firmage_rel share_manf_rel share_whole_rel, by(fgp_firm year)


  
sort fgp_firm year
*browse fgp_firm year firms  emp*
*browse fgp_firm year wage plants firmage share_manf share_whole

*Output Firm Table Stats
outsheet fgp_firm year firms emp_tot emp_manf emp_manf_rel emp_whol* emp_serv* emp_othr* emp_mpro* wage* plants* firmage* share_manf* share_whole* using "$disc/output/Firm_Panel_Stats.out", comma replace


**Calculate disclosure statistics
use temp.dta, clear
keep firmid emp year fgp_firm


*Calculate Disclosure Stats 
   capture log close
     log using $disc/support/Firm_Panel_Stats_Disc.txt, replace text
     qui log off
      gen tvs=emp
      save temp.dta, replace
 
     foreach var in YES NO {
       forvalues i=1992/2007 {
         keep if fgp_firm=="`var'" & year==`i'
	 qui log on
	 di "FGP Firm Status is `var' and year is `i'" 
	 qui log off
	 do disclose_firm_level
	 use temp.dta, clear
	 }
	 }

erase temp.dta


	 

